@@ -1,4 +1,5 @@
-from sqlalchemy import *
+from sqlalchemy import MetaData, Table, Column, String, Unicode, Integer, \
+    create_engine
 from sqlalchemy.testing import fixtures, AssertsExecutionResults, profiling
 from sqlalchemy import testing
 from sqlalchemy.testing import eq_
@@ -9,6 +10,8 @@ import sys
 NUM_FIELDS = 10
 NUM_RECORDS = 1000
 
+t = t2 = metadata = None
+
 
 class ResultSetTest(fixtures.TestBase, AssertsExecutionResults):
     __backend__ = True
@@ -17,23 +20,31 @@ class ResultSetTest(fixtures.TestBase, AssertsExecutionResults):
     def setup_class(cls):
         global t, t2, metadata
         metadata = MetaData(testing.db)
-        t = Table('table', metadata, *[Column('field%d' % fnum, String(50))
-                  for fnum in range(NUM_FIELDS)])
-        t2 = Table('table2', metadata, *[Column('field%d' % fnum,
-                   Unicode(50)) for fnum in range(NUM_FIELDS)])
+        t = Table('table1', metadata, *[Column('field%d' % fnum, String(50))
+                                        for fnum in range(NUM_FIELDS)])
+        t2 = Table(
+            'table2', metadata, *
+            [Column('field%d' % fnum, Unicode(50))
+             for fnum in range(NUM_FIELDS)])
 
     def setup(self):
         metadata.create_all()
         t.insert().execute([dict(('field%d' % fnum, u('value%d' % fnum))
-                           for fnum in range(NUM_FIELDS)) for r_num in
-                           range(NUM_RECORDS)])
-        t2.insert().execute([dict(('field%d' % fnum, u('value%d' % fnum))
-                            for fnum in range(NUM_FIELDS)) for r_num in
+                                 for fnum in range(NUM_FIELDS)) for r_num in
                             range(NUM_RECORDS)])
+        t2.insert().execute([dict(('field%d' % fnum, u('value%d' % fnum))
+                                  for fnum in range(NUM_FIELDS)) for r_num in
+                             range(NUM_RECORDS)])
 
         # warm up type caches
         t.select().execute().fetchall()
         t2.select().execute().fetchall()
+        testing.db.execute('SELECT %s FROM table1' % (
+            ", ".join("field%d" % fnum for fnum in range(NUM_FIELDS))
+        )).fetchall()
+        testing.db.execute("SELECT %s FROM table2" % (
+            ", ".join("field%d" % fnum for fnum in range(NUM_FIELDS))
+        )).fetchall()
 
     def teardown(self):
         metadata.drop_all()
@@ -46,9 +57,25 @@ class ResultSetTest(fixtures.TestBase, AssertsExecutionResults):
     def test_unicode(self):
         [tuple(row) for row in t2.select().execute().fetchall()]
 
+    @profiling.function_call_count(variance=0.10)
+    def test_raw_string(self):
+        stmt = 'SELECT %s FROM table1' % (
+            ", ".join("field%d" % fnum for fnum in range(NUM_FIELDS))
+        )
+        [tuple(row) for row in testing.db.execute(stmt).fetchall()]
+
+    @profiling.function_call_count(variance=0.10)
+    def test_raw_unicode(self):
+        stmt = "SELECT %s FROM table2" % (
+            ", ".join("field%d" % fnum for fnum in range(NUM_FIELDS))
+        )
+        [tuple(row) for row in testing.db.execute(stmt).fetchall()]
+
     def test_contains_doesnt_compile(self):
         row = t.select().execute().first()
-        c1 = Column('some column', Integer) + Column("some other column", Integer)
+        c1 = Column('some column', Integer) + \
+            Column("some other column", Integer)
+
         @profiling.function_call_count()
         def go():
             c1 in row
@@ -68,9 +95,12 @@ class ExecutionTest(fixtures.TestBase):
         @profiling.function_call_count()
         def go():
             c.execute("select 1")
-        go()
+        try:
+            go()
+        finally:
+            c.close()
 
-    def test_minimal_engine_execute(self):
+    def test_minimal_engine_execute(self, variance=0.10):
         # create an engine without any instrumentation.
         e = create_engine('sqlite://')
         # ensure initial connect activities complete
@@ -88,6 +118,7 @@ class RowProxyTest(fixtures.TestBase):
 
     def _rowproxy_fixture(self, keys, processors, row):
         class MockMeta(object):
+
             def __init__(self):
                 pass
 
@@ -95,7 +126,7 @@ class RowProxyTest(fixtures.TestBase):
 
         keymap = {}
         for index, (keyobjs, processor, values) in \
-            enumerate(list(zip(keys, processors, row))):
+                enumerate(list(zip(keys, processors, row))):
             for key in keyobjs:
                 keymap[key] = (processor, key, index)
             keymap[index] = (processor, key, index)
@@ -103,6 +134,7 @@ class RowProxyTest(fixtures.TestBase):
 
     def _test_getitem_value_refcounts(self, seq_factory):
         col1, col2 = object(), object()
+
         def proc1(value):
             return value
         value1, value2 = "x", "y"
@@ -130,6 +162,7 @@ class RowProxyTest(fixtures.TestBase):
 
     def test_value_refcounts_custom_seq(self):
         class CustomSeq(object):
+
             def __init__(self, data):
                 self.data = data
 
